Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorHarald Mackamul2018-10-29 15:43:10 +0000
committerHarald Mackamul2018-10-30 13:02:03 +0000
commit91c950a46176714b31a98355387dc63fbf9cdc77 (patch)
tree347dc97f3177b34f9824e3481a4a3bfe5356871b
parentabffedfdc2cf53cb251db8c5463533439a9af7b2 (diff)
downloadorg.eclipse.app4mc-91c950a46176714b31a98355387dc63fbf9cdc77.tar.gz
org.eclipse.app4mc-91c950a46176714b31a98355387dc63fbf9cdc77.tar.xz
org.eclipse.app4mc-91c950a46176714b31a98355387dc63fbf9cdc77.zip
Hardware model: minor changes for attributes of ConnectionHandler
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model.edit/plugin.properties2
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model.edit/src-gen/org/eclipse/app4mc/amalthea/model/provider/ConnectionHandlerDefinitionItemProvider.java52
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xml-schema-definitions.zipbin43114 -> 43117 bytes
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xsd/amalthea.xsd5
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model/model/AmaltheaXMI.xsd5
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model/model/amalthea.xcore5
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/AmaltheaPackage.java46
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/ConnectionHandlerDefinition.java71
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/AmaltheaPackageImpl.java23
-rw-r--r--plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/ConnectionHandlerDefinitionImpl.java146
10 files changed, 109 insertions, 246 deletions
diff --git a/plugins/org.eclipse.app4mc.amalthea.model.edit/plugin.properties b/plugins/org.eclipse.app4mc.amalthea.model.edit/plugin.properties
index bc021f40a..d4f65b3ea 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model.edit/plugin.properties
+++ b/plugins/org.eclipse.app4mc.amalthea.model.edit/plugin.properties
@@ -1504,3 +1504,5 @@ _UI_MemoryType_FLASH_EXT_literal = FLASH_EXT
_UI_MemoryType_PCM_literal = PCM
_UI_MemoryType_FLASH_literal = FLASH
_UI_HwStructure_innerPorts_feature = Inner Ports
+_UI_ConnectionHandlerDefinition_maxBurstSize_feature = Max Burst Size
+_UI_ConnectionHandlerDefinition_maxConcurrentTransfers_feature = Max Concurrent Transfers
diff --git a/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xml-schema-definitions.zip b/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xml-schema-definitions.zip
index 91dc6f061..1d6331b98 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xml-schema-definitions.zip
+++ b/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xml-schema-definitions.zip
Binary files differ
diff --git a/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xsd/amalthea.xsd b/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xsd/amalthea.xsd
index 9a0fb3602..aab93842f 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xsd/amalthea.xsd
+++ b/plugins/org.eclipse.app4mc.amalthea.model.help/help-model/xsd/amalthea.xsd
@@ -3077,9 +3077,8 @@ entity: The component that fires the event (optional)</xsd:documentation>
<xsd:element name="dataRate" type="am:DataRate"/>
</xsd:choice>
<xsd:attribute name="policy" type="am:SchedPolicy"/>
- <xsd:attribute name="bitWidth" type="xsd:int"/>
- <xsd:attribute name="burstSize" type="xsd:string"/>
- <xsd:attribute name="parallelTransactions" type="xsd:string"/>
+ <xsd:attribute name="maxBurstSize" type="xsd:string"/>
+ <xsd:attribute name="maxConcurrentTransfers" type="xsd:string"/>
</xsd:extension>
</xsd:complexContent>
</xsd:complexType>
diff --git a/plugins/org.eclipse.app4mc.amalthea.model/model/AmaltheaXMI.xsd b/plugins/org.eclipse.app4mc.amalthea.model/model/AmaltheaXMI.xsd
index 9a0fb3602..aab93842f 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model/model/AmaltheaXMI.xsd
+++ b/plugins/org.eclipse.app4mc.amalthea.model/model/AmaltheaXMI.xsd
@@ -3077,9 +3077,8 @@ entity: The component that fires the event (optional)</xsd:documentation>
<xsd:element name="dataRate" type="am:DataRate"/>
</xsd:choice>
<xsd:attribute name="policy" type="am:SchedPolicy"/>
- <xsd:attribute name="bitWidth" type="xsd:int"/>
- <xsd:attribute name="burstSize" type="xsd:string"/>
- <xsd:attribute name="parallelTransactions" type="xsd:string"/>
+ <xsd:attribute name="maxBurstSize" type="xsd:string"/>
+ <xsd:attribute name="maxConcurrentTransfers" type="xsd:string"/>
</xsd:extension>
</xsd:complexContent>
</xsd:complexType>
diff --git a/plugins/org.eclipse.app4mc.amalthea.model/model/amalthea.xcore b/plugins/org.eclipse.app4mc.amalthea.model/model/amalthea.xcore
index 495df61c9..a78ba27f1 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model/model/amalthea.xcore
+++ b/plugins/org.eclipse.app4mc.amalthea.model/model/amalthea.xcore
@@ -1824,9 +1824,8 @@ class ConnectionHandlerDefinition extends HwDefinition
contains HwLatency readLatency
contains HwLatency writeLatency
contains DataRate dataRate
- int bitWidth
- PositiveInt burstSize = "1"
- PositiveInt parallelTransactions = "1"
+ PositiveInt maxBurstSize = "1"
+ PositiveInt maxConcurrentTransfers = "1"
}
class MemoryDefinition extends HwDefinition
diff --git a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/AmaltheaPackageImpl.java b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/AmaltheaPackageImpl.java
index 4376d6798..88f52365e 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/AmaltheaPackageImpl.java
+++ b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/AmaltheaPackageImpl.java
@@ -7433,7 +7433,7 @@ public class AmaltheaPackageImpl extends EPackageImpl implements AmaltheaPackage
* <!-- end-user-doc -->
* @generated
*/
- public EAttribute getConnectionHandlerDefinition_BitWidth() {
+ public EAttribute getConnectionHandlerDefinition_MaxBurstSize() {
return (EAttribute)connectionHandlerDefinitionEClass.getEStructuralFeatures().get(4);
}
@@ -7442,7 +7442,7 @@ public class AmaltheaPackageImpl extends EPackageImpl implements AmaltheaPackage
* <!-- end-user-doc -->
* @generated
*/
- public EAttribute getConnectionHandlerDefinition_BurstSize() {
+ public EAttribute getConnectionHandlerDefinition_MaxConcurrentTransfers() {
return (EAttribute)connectionHandlerDefinitionEClass.getEStructuralFeatures().get(5);
}
@@ -7451,15 +7451,6 @@ public class AmaltheaPackageImpl extends EPackageImpl implements AmaltheaPackage
* <!-- end-user-doc -->
* @generated
*/
- public EAttribute getConnectionHandlerDefinition_ParallelTransactions() {
- return (EAttribute)connectionHandlerDefinitionEClass.getEStructuralFeatures().get(6);
- }
-
- /**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- */
public EClass getMemoryDefinition() {
return memoryDefinitionEClass;
}
@@ -13761,9 +13752,8 @@ public class AmaltheaPackageImpl extends EPackageImpl implements AmaltheaPackage
createEReference(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__READ_LATENCY);
createEReference(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__WRITE_LATENCY);
createEReference(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__DATA_RATE);
- createEAttribute(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__BIT_WIDTH);
- createEAttribute(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__BURST_SIZE);
- createEAttribute(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS);
+ createEAttribute(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE);
+ createEAttribute(connectionHandlerDefinitionEClass, CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS);
memoryDefinitionEClass = createEClass(MEMORY_DEFINITION);
createEReference(memoryDefinitionEClass, MEMORY_DEFINITION__SIZE);
@@ -15688,9 +15678,8 @@ public class AmaltheaPackageImpl extends EPackageImpl implements AmaltheaPackage
initEReference(getConnectionHandlerDefinition_ReadLatency(), this.getHwLatency(), null, "readLatency", null, 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getConnectionHandlerDefinition_WriteLatency(), this.getHwLatency(), null, "writeLatency", null, 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getConnectionHandlerDefinition_DataRate(), this.getDataRate(), null, "dataRate", null, 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEAttribute(getConnectionHandlerDefinition_BitWidth(), theEcorePackage.getEInt(), "bitWidth", null, 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEAttribute(getConnectionHandlerDefinition_BurstSize(), this.getPositiveInt(), "burstSize", "1", 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEAttribute(getConnectionHandlerDefinition_ParallelTransactions(), this.getPositiveInt(), "parallelTransactions", "1", 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEAttribute(getConnectionHandlerDefinition_MaxBurstSize(), this.getPositiveInt(), "maxBurstSize", "1", 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEAttribute(getConnectionHandlerDefinition_MaxConcurrentTransfers(), this.getPositiveInt(), "maxConcurrentTransfers", "1", 0, 1, ConnectionHandlerDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(memoryDefinitionEClass, MemoryDefinition.class, "MemoryDefinition", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
initEReference(getMemoryDefinition_Size(), this.getDataSize(), null, "size", null, 0, 1, MemoryDefinition.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
diff --git a/plugins/org.eclipse.app4mc.amalthea.model.edit/src-gen/org/eclipse/app4mc/amalthea/model/provider/ConnectionHandlerDefinitionItemProvider.java b/plugins/org.eclipse.app4mc.amalthea.model.edit/src-gen/org/eclipse/app4mc/amalthea/model/provider/ConnectionHandlerDefinitionItemProvider.java
index 803a80277..e0d163c51 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model.edit/src-gen/org/eclipse/app4mc/amalthea/model/provider/ConnectionHandlerDefinitionItemProvider.java
+++ b/plugins/org.eclipse.app4mc.amalthea.model.edit/src-gen/org/eclipse/app4mc/amalthea/model/provider/ConnectionHandlerDefinitionItemProvider.java
@@ -61,9 +61,8 @@ public class ConnectionHandlerDefinitionItemProvider extends HwDefinitionItemPro
super.getPropertyDescriptors(object);
addPolicyPropertyDescriptor(object);
- addBitWidthPropertyDescriptor(object);
- addBurstSizePropertyDescriptor(object);
- addParallelTransactionsPropertyDescriptor(object);
+ addMaxBurstSizePropertyDescriptor(object);
+ addMaxConcurrentTransfersPropertyDescriptor(object);
}
return itemPropertyDescriptors;
}
@@ -91,19 +90,19 @@ public class ConnectionHandlerDefinitionItemProvider extends HwDefinitionItemPro
}
/**
* This adds a property descriptor for the Bit Width feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
*/
- protected void addBitWidthPropertyDescriptor(Object object) {
+ protected void addMaxBurstSizePropertyDescriptor(Object object) {
itemPropertyDescriptors.add
(createItemPropertyDescriptor
(((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
getResourceLocator(),
- getString("_UI_ConnectionHandlerDefinition_bitWidth_feature"),
- getString("_UI_PropertyDescriptor_description", "_UI_ConnectionHandlerDefinition_bitWidth_feature", "_UI_ConnectionHandlerDefinition_type"),
- AmaltheaPackage.eINSTANCE.getConnectionHandlerDefinition_BitWidth(),
+ getString("_UI_ConnectionHandlerDefinition_maxBurstSize_feature"),
+ getString("_UI_PropertyDescriptor_description", "_UI_ConnectionHandlerDefinition_maxBurstSize_feature", "_UI_ConnectionHandlerDefinition_type"),
+ AmaltheaPackage.eINSTANCE.getConnectionHandlerDefinition_MaxBurstSize(),
true,
false,
false,
@@ -113,41 +112,19 @@ public class ConnectionHandlerDefinitionItemProvider extends HwDefinitionItemPro
}
/**
* This adds a property descriptor for the Burst Size feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
*/
- protected void addBurstSizePropertyDescriptor(Object object) {
+ protected void addMaxConcurrentTransfersPropertyDescriptor(Object object) {
itemPropertyDescriptors.add
(createItemPropertyDescriptor
(((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
getResourceLocator(),
- getString("_UI_ConnectionHandlerDefinition_burstSize_feature"),
- getString("_UI_PropertyDescriptor_description", "_UI_ConnectionHandlerDefinition_burstSize_feature", "_UI_ConnectionHandlerDefinition_type"),
- AmaltheaPackage.eINSTANCE.getConnectionHandlerDefinition_BurstSize(),
- true,
- false,
- false,
- ItemPropertyDescriptor.INTEGRAL_VALUE_IMAGE,
- null,
- null));
- }
-
- /**
- * This adds a property descriptor for the Parallel Transactions feature.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- */
- protected void addParallelTransactionsPropertyDescriptor(Object object) {
- itemPropertyDescriptors.add
- (createItemPropertyDescriptor
- (((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
- getResourceLocator(),
- getString("_UI_ConnectionHandlerDefinition_parallelTransactions_feature"),
- getString("_UI_PropertyDescriptor_description", "_UI_ConnectionHandlerDefinition_parallelTransactions_feature", "_UI_ConnectionHandlerDefinition_type"),
- AmaltheaPackage.eINSTANCE.getConnectionHandlerDefinition_ParallelTransactions(),
+ getString("_UI_ConnectionHandlerDefinition_maxConcurrentTransfers_feature"),
+ getString("_UI_PropertyDescriptor_description", "_UI_ConnectionHandlerDefinition_maxConcurrentTransfers_feature", "_UI_ConnectionHandlerDefinition_type"),
+ AmaltheaPackage.eINSTANCE.getConnectionHandlerDefinition_MaxConcurrentTransfers(),
true,
false,
false,
@@ -237,9 +214,8 @@ public class ConnectionHandlerDefinitionItemProvider extends HwDefinitionItemPro
switch (notification.getFeatureID(ConnectionHandlerDefinition.class)) {
case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__POLICY:
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BIT_WIDTH:
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BURST_SIZE:
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS:
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE:
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS:
fireNotifyChanged(new ViewerNotification(notification, notification.getNotifier(), false, true));
return;
case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__READ_LATENCY:
@@ -91,19 +90,19 @@ public class ConnectionHandlerDefinitionItemProvider extends HwDefinitionItemPro
}
/**
- * This adds a property descriptor for the Bit Width feature.
+ * This adds a property descriptor for the Max Burst Size feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -113,41 +112,19 @@ public class ConnectionHandlerDefinitionItemProvider extends HwDefinitionItemPro
}
/**
- * This adds a property descriptor for the Burst Size feature.
+ * This adds a property descriptor for the Max Concurrent Transfers feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
diff --git a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/AmaltheaPackage.java b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/AmaltheaPackage.java
index 9ef6a1934..7dcdd96c9 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/AmaltheaPackage.java
+++ b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/AmaltheaPackage.java
@@ -12641,31 +12641,22 @@ public interface AmaltheaPackage extends EPackage {
int CONNECTION_HANDLER_DEFINITION__DATA_RATE = HW_DEFINITION_FEATURE_COUNT + 3;
/**
- * The feature id for the '<em><b>Bit Width</b></em>' attribute.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- * @ordered
- */
- int CONNECTION_HANDLER_DEFINITION__BIT_WIDTH = HW_DEFINITION_FEATURE_COUNT + 4;
-
- /**
- * The feature id for the '<em><b>Burst Size</b></em>' attribute.
+ * The feature id for the '<em><b>Max Burst Size</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int CONNECTION_HANDLER_DEFINITION__BURST_SIZE = HW_DEFINITION_FEATURE_COUNT + 5;
+ int CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE = HW_DEFINITION_FEATURE_COUNT + 4;
/**
- * The feature id for the '<em><b>Parallel Transactions</b></em>' attribute.
+ * The feature id for the '<em><b>Max Concurrent Transfers</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS = HW_DEFINITION_FEATURE_COUNT + 6;
+ int CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS = HW_DEFINITION_FEATURE_COUNT + 5;
/**
* The number of structural features of the '<em>Connection Handler Definition</em>' class.
@@ -12674,7 +12665,7 @@ public interface AmaltheaPackage extends EPackage {
* @generated
* @ordered
*/
- int CONNECTION_HANDLER_DEFINITION_FEATURE_COUNT = HW_DEFINITION_FEATURE_COUNT + 7;
+ int CONNECTION_HANDLER_DEFINITION_FEATURE_COUNT = HW_DEFINITION_FEATURE_COUNT + 6;
/**
* The operation id for the '<em>Compute Unique Name</em>' operation.
@@ -32834,37 +32825,26 @@ public interface AmaltheaPackage extends EPackage {
EReference getConnectionHandlerDefinition_DataRate();
/**
- * Returns the meta object for the attribute '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBitWidth <em>Bit Width</em>}'.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @return the meta object for the attribute '<em>Bit Width</em>'.
- * @see org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBitWidth()
- * @see #getConnectionHandlerDefinition()
- * @generated
- */
- EAttribute getConnectionHandlerDefinition_BitWidth();
-
- /**
- * Returns the meta object for the attribute '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBurstSize <em>Burst Size</em>}'.
+ * Returns the meta object for the attribute '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxBurstSize <em>Max Burst Size</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the attribute '<em>Burst Size</em>'.
* @see org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBurstSize()
* @see #getConnectionHandlerDefinition()
* @generated
*/
- EAttribute getConnectionHandlerDefinition_BurstSize();
+ EAttribute getConnectionHandlerDefinition_MaxBurstSize();
/**
* Returns the meta object for the attribute '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions <em>Parallel Transactions</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the attribute '<em>Parallel Transactions</em>'.
* @see org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions()
* @see #getConnectionHandlerDefinition()
* @generated
*/
- EAttribute getConnectionHandlerDefinition_ParallelTransactions();
+ EAttribute getConnectionHandlerDefinition_MaxConcurrentTransfers();
/**
* Returns the meta object for class '{@link org.eclipse.app4mc.amalthea.model.MemoryDefinition <em>Memory Definition</em>}'.
@@ -32834,37 +32825,26 @@ public interface AmaltheaPackage extends EPackage {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return the meta object for the attribute '<em>Burst Size</em>'.
- * @see org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBurstSize()
+ * @return the meta object for the attribute '<em>Max Burst Size</em>'.
+ * @see org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxBurstSize()
* @see #getConnectionHandlerDefinition()
* @generated
@@ -32834,37 +32825,26 @@ public interface AmaltheaPackage extends EPackage {
/**
- * Returns the meta object for the attribute '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions <em>Parallel Transactions</em>}'.
+ * Returns the meta object for the attribute '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxConcurrentTransfers <em>Max Concurrent Transfers</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -32834,37 +32825,26 @@ public interface AmaltheaPackage extends EPackage {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return the meta object for the attribute '<em>Parallel Transactions</em>'.
- * @see org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions()
+ * @return the meta object for the attribute '<em>Max Concurrent Transfers</em>'.
+ * @see org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxConcurrentTransfers()
* @see #getConnectionHandlerDefinition()
* @generated
diff --git a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/ConnectionHandlerDefinition.java b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/ConnectionHandlerDefinition.java
index a1c35f2fc..9f7a4866f 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/ConnectionHandlerDefinition.java
+++ b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/ConnectionHandlerDefinition.java
@@ -28,9 +28,8 @@ package org.eclipse.app4mc.amalthea.model;
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getReadLatency <em>Read Latency</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getWriteLatency <em>Write Latency</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getDataRate <em>Data Rate</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBitWidth <em>Bit Width</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBurstSize <em>Burst Size</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions <em>Parallel Transactions</em>}</li>
* </ul>
*
* @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition()
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
void setDataRate(DataRate value);
/**
- * Returns the value of the '<em><b>Bit Width</b></em>' attribute.
- * <!-- begin-user-doc -->
- * <p>
- * If the meaning of the '<em>Bit Width</em>' attribute isn't clear,
- * there really should be more of a description here...
- * </p>
- * <!-- end-user-doc -->
- * @return the value of the '<em>Bit Width</em>' attribute.
- * @see #setBitWidth(int)
- * @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition_BitWidth()
- * @model unique="false"
- * @generated
- */
- int getBitWidth();
-
- /**
- * Sets the value of the '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBitWidth <em>Bit Width</em>}' attribute.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @param value the new value of the '<em>Bit Width</em>' attribute.
- * @see #getBitWidth()
- * @generated
- */
- void setBitWidth(int value);
-
- /**
- * Returns the value of the '<em><b>Burst Size</b></em>' attribute.
+ * Returns the value of the '<em><b>Max Burst Size</b></em>' attribute.
* The default value is <code>"1"</code>.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Burst Size</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Burst Size</em>' attribute.
* @see #setBurstSize(int)
* @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition_BurstSize()
* @model default="1" unique="false" dataType="org.eclipse.app4mc.amalthea.model.PositiveInt"
* @generated
*/
- int getBurstSize();
+ int getMaxBurstSize();
/**
* Sets the value of the '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBurstSize <em>Burst Size</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Burst Size</em>' attribute.
* @see #getBurstSize()
* @generated
*/
- void setBurstSize(int value);
+ void setMaxBurstSize(int value);
/**
- * Returns the value of the '<em><b>Parallel Transactions</b></em>' attribute.
+ * Returns the value of the '<em><b>Max Concurrent Transfers</b></em>' attribute.
* The default value is <code>"1"</code>.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Parallel Transactions</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Parallel Transactions</em>' attribute.
* @see #setParallelTransactions(int)
* @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition_ParallelTransactions()
* @model default="1" unique="false" dataType="org.eclipse.app4mc.amalthea.model.PositiveInt"
* @generated
*/
- int getParallelTransactions();
+ int getMaxConcurrentTransfers();
/**
* Sets the value of the '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions <em>Parallel Transactions</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Parallel Transactions</em>' attribute.
* @see #getParallelTransactions()
* @generated
*/
- void setParallelTransactions(int value);
+ void setMaxConcurrentTransfers(int value);
} // ConnectionHandlerDefinition
@@ -28,9 +28,8 @@ package org.eclipse.app4mc.amalthea.model;
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getWriteLatency <em>Write Latency</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getDataRate <em>Data Rate</em>}</li>
- * <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBitWidth <em>Bit Width</em>}</li>
- * <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBurstSize <em>Burst Size</em>}</li>
- * <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions <em>Parallel Transactions</em>}</li>
+ * <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxBurstSize <em>Max Burst Size</em>}</li>
+ * <li>{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxConcurrentTransfers <em>Max Concurrent Transfers</em>}</li>
* </ul>
*
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Burst Size</em>' attribute isn't clear,
+ * If the meaning of the '<em>Max Burst Size</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Burst Size</em>' attribute.
- * @see #setBurstSize(int)
- * @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition_BurstSize()
+ * @return the value of the '<em>Max Burst Size</em>' attribute.
+ * @see #setMaxBurstSize(int)
+ * @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition_MaxBurstSize()
* @model default="1" unique="false" dataType="org.eclipse.app4mc.amalthea.model.PositiveInt"
* @generated
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
/**
- * Sets the value of the '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getBurstSize <em>Burst Size</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxBurstSize <em>Max Burst Size</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Burst Size</em>' attribute.
- * @see #getBurstSize()
+ * @param value the new value of the '<em>Max Burst Size</em>' attribute.
+ * @see #getMaxBurstSize()
* @generated
*/
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Parallel Transactions</em>' attribute isn't clear,
+ * If the meaning of the '<em>Max Concurrent Transfers</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Parallel Transactions</em>' attribute.
- * @see #setParallelTransactions(int)
- * @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition_ParallelTransactions()
+ * @return the value of the '<em>Max Concurrent Transfers</em>' attribute.
+ * @see #setMaxConcurrentTransfers(int)
+ * @see org.eclipse.app4mc.amalthea.model.AmaltheaPackage#getConnectionHandlerDefinition_MaxConcurrentTransfers()
* @model default="1" unique="false" dataType="org.eclipse.app4mc.amalthea.model.PositiveInt"
* @generated
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
/**
- * Sets the value of the '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getParallelTransactions <em>Parallel Transactions</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.app4mc.amalthea.model.ConnectionHandlerDefinition#getMaxConcurrentTransfers <em>Max Concurrent Transfers</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -146,83 +145,57 @@ public interface ConnectionHandlerDefinition extends HwDefinition {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Parallel Transactions</em>' attribute.
- * @see #getParallelTransactions()
+ * @param value the new value of the '<em>Max Concurrent Transfers</em>' attribute.
+ * @see #getMaxConcurrentTransfers()
* @generated
*/
diff --git a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/ConnectionHandlerDefinitionImpl.java b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/ConnectionHandlerDefinitionImpl.java
index 6a6de4161..40e84eee4 100644
--- a/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/ConnectionHandlerDefinitionImpl.java
+++ b/plugins/org.eclipse.app4mc.amalthea.model/src-gen/org/eclipse/app4mc/amalthea/model/impl/ConnectionHandlerDefinitionImpl.java
@@ -40,9 +40,8 @@ import org.eclipse.emf.ecore.impl.ENotificationImpl;
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getReadLatency <em>Read Latency</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getWriteLatency <em>Write Latency</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getDataRate <em>Data Rate</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getBitWidth <em>Bit Width</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getBurstSize <em>Burst Size</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getParallelTransactions <em>Parallel Transactions</em>}</li>
* </ul>
*
* @generated
@@ -99,64 +98,44 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
protected DataRate dataRate;
/**
* The default value of the '{@link #getBitWidth() <em>Bit Width</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getBitWidth()
+ * @see #getMaxBurstSize()
* @generated
* @ordered
*/
- protected static final int BIT_WIDTH_EDEFAULT = 0;
+ protected static final int MAX_BURST_SIZE_EDEFAULT = 1;
/**
* The cached value of the '{@link #getBitWidth() <em>Bit Width</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getBitWidth()
+ * @see #getMaxBurstSize()
* @generated
* @ordered
*/
- protected int bitWidth = BIT_WIDTH_EDEFAULT;
+ protected int maxBurstSize = MAX_BURST_SIZE_EDEFAULT;
/**
* The default value of the '{@link #getBurstSize() <em>Burst Size</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getBurstSize()
+ * @see #getMaxConcurrentTransfers()
* @generated
* @ordered
*/
- protected static final int BURST_SIZE_EDEFAULT = 1;
+ protected static final int MAX_CONCURRENT_TRANSFERS_EDEFAULT = 1;
/**
* The cached value of the '{@link #getBurstSize() <em>Burst Size</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getBurstSize()
+ * @see #getMaxConcurrentTransfers()
* @generated
* @ordered
*/
- protected int burstSize = BURST_SIZE_EDEFAULT;
-
- /**
- * The default value of the '{@link #getParallelTransactions() <em>Parallel Transactions</em>}' attribute.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @see #getParallelTransactions()
- * @generated
- * @ordered
- */
- protected static final int PARALLEL_TRANSACTIONS_EDEFAULT = 1;
-
- /**
- * The cached value of the '{@link #getParallelTransactions() <em>Parallel Transactions</em>}' attribute.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @see #getParallelTransactions()
- * @generated
- * @ordered
- */
- protected int parallelTransactions = PARALLEL_TRANSACTIONS_EDEFAULT;
+ protected int maxConcurrentTransfers = MAX_CONCURRENT_TRANSFERS_EDEFAULT;
/**
* <!-- begin-user-doc -->
@@ -332,8 +311,8 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
* <!-- end-user-doc -->
* @generated
*/
- public int getBitWidth() {
- return bitWidth;
+ public int getMaxBurstSize() {
+ return maxBurstSize;
}
/**
@@ -341,11 +320,11 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
* <!-- end-user-doc -->
* @generated
*/
- public void setBitWidth(int newBitWidth) {
- int oldBitWidth = bitWidth;
- bitWidth = newBitWidth;
+ public void setMaxBurstSize(int newMaxBurstSize) {
+ int oldMaxBurstSize = maxBurstSize;
+ maxBurstSize = newMaxBurstSize;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BIT_WIDTH, oldBitWidth, bitWidth));
+ eNotify(new ENotificationImpl(this, Notification.SET, AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE, oldMaxBurstSize, maxBurstSize));
}
/**
@@ -353,8 +332,8 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
* <!-- end-user-doc -->
* @generated
*/
- public int getBurstSize() {
- return burstSize;
+ public int getMaxConcurrentTransfers() {
+ return maxConcurrentTransfers;
}
/**
@@ -362,32 +341,11 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
* <!-- end-user-doc -->
* @generated
*/
- public void setBurstSize(int newBurstSize) {
- int oldBurstSize = burstSize;
- burstSize = newBurstSize;
+ public void setMaxConcurrentTransfers(int newMaxConcurrentTransfers) {
+ int oldMaxConcurrentTransfers = maxConcurrentTransfers;
+ maxConcurrentTransfers = newMaxConcurrentTransfers;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BURST_SIZE, oldBurstSize, burstSize));
- }
-
- /**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- */
- public int getParallelTransactions() {
- return parallelTransactions;
- }
-
- /**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- */
- public void setParallelTransactions(int newParallelTransactions) {
- int oldParallelTransactions = parallelTransactions;
- parallelTransactions = newParallelTransactions;
- if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS, oldParallelTransactions, parallelTransactions));
+ eNotify(new ENotificationImpl(this, Notification.SET, AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS, oldMaxConcurrentTransfers, maxConcurrentTransfers));
}
/**
@@ -424,12 +382,10 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
return getWriteLatency();
case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__DATA_RATE:
return getDataRate();
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BIT_WIDTH:
- return getBitWidth();
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BURST_SIZE:
- return getBurstSize();
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS:
- return getParallelTransactions();
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE:
+ return getMaxBurstSize();
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS:
+ return getMaxConcurrentTransfers();
}
return super.eGet(featureID, resolve, coreType);
}
@@ -454,14 +410,11 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__DATA_RATE:
setDataRate((DataRate)newValue);
return;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BIT_WIDTH:
- setBitWidth((Integer)newValue);
- return;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BURST_SIZE:
- setBurstSize((Integer)newValue);
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE:
+ setMaxBurstSize((Integer)newValue);
return;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS:
- setParallelTransactions((Integer)newValue);
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS:
+ setMaxConcurrentTransfers((Integer)newValue);
return;
}
super.eSet(featureID, newValue);
@@ -487,14 +440,11 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__DATA_RATE:
setDataRate((DataRate)null);
return;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BIT_WIDTH:
- setBitWidth(BIT_WIDTH_EDEFAULT);
- return;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BURST_SIZE:
- setBurstSize(BURST_SIZE_EDEFAULT);
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE:
+ setMaxBurstSize(MAX_BURST_SIZE_EDEFAULT);
return;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS:
- setParallelTransactions(PARALLEL_TRANSACTIONS_EDEFAULT);
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS:
+ setMaxConcurrentTransfers(MAX_CONCURRENT_TRANSFERS_EDEFAULT);
return;
}
super.eUnset(featureID);
@@ -516,12 +466,10 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
return writeLatency != null;
case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__DATA_RATE:
return dataRate != null;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BIT_WIDTH:
- return bitWidth != BIT_WIDTH_EDEFAULT;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__BURST_SIZE:
- return burstSize != BURST_SIZE_EDEFAULT;
- case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__PARALLEL_TRANSACTIONS:
- return parallelTransactions != PARALLEL_TRANSACTIONS_EDEFAULT;
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_BURST_SIZE:
+ return maxBurstSize != MAX_BURST_SIZE_EDEFAULT;
+ case AmaltheaPackage.CONNECTION_HANDLER_DEFINITION__MAX_CONCURRENT_TRANSFERS:
+ return maxConcurrentTransfers != MAX_CONCURRENT_TRANSFERS_EDEFAULT;
}
return super.eIsSet(featureID);
}
@@ -538,12 +486,10 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
StringBuilder result = new StringBuilder(super.toString());
result.append(" (policy: ");
result.append(policy);
- result.append(", bitWidth: ");
- result.append(bitWidth);
- result.append(", burstSize: ");
- result.append(burstSize);
- result.append(", parallelTransactions: ");
- result.append(parallelTransactions);
+ result.append(", maxBurstSize: ");
+ result.append(maxBurstSize);
+ result.append(", maxConcurrentTransfers: ");
+ result.append(maxConcurrentTransfers);
result.append(')');
return result.toString();
}
@@ -40,9 +40,8 @@ import org.eclipse.emf.ecore.impl.ENotificationImpl;
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getWriteLatency <em>Write Latency</em>}</li>
* <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getDataRate <em>Data Rate</em>}</li>
- * <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getBitWidth <em>Bit Width</em>}</li>
- * <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getBurstSize <em>Burst Size</em>}</li>
- * <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getParallelTransactions <em>Parallel Transactions</em>}</li>
+ * <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getMaxBurstSize <em>Max Burst Size</em>}</li>
+ * <li>{@link org.eclipse.app4mc.amalthea.model.impl.ConnectionHandlerDefinitionImpl#getMaxConcurrentTransfers <em>Max Concurrent Transfers</em>}</li>
* </ul>
*
@@ -99,64 +98,44 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
protected DataRate dataRate;
/**
- * The default value of the '{@link #getBitWidth() <em>Bit Width</em>}' attribute.
+ * The default value of the '{@link #getMaxBurstSize() <em>Max Burst Size</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -99,64 +98,44 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
/**
- * The cached value of the '{@link #getBitWidth() <em>Bit Width</em>}' attribute.
+ * The cached value of the '{@link #getMaxBurstSize() <em>Max Burst Size</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -99,64 +98,44 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
/**
- * The default value of the '{@link #getBurstSize() <em>Burst Size</em>}' attribute.
+ * The default value of the '{@link #getMaxConcurrentTransfers() <em>Max Concurrent Transfers</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -99,64 +98,44 @@ public class ConnectionHandlerDefinitionImpl extends HwDefinitionImpl implements
/**
- * The cached value of the '{@link #getBurstSize() <em>Burst Size</em>}' attribute.
+ * The cached value of the '{@link #getMaxConcurrentTransfers() <em>Max Concurrent Transfers</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->

Back to the top